@@ -33,17 +33,8 @@ from PyQt5.QtWidgets import (
     )
 from PyQt5.QtCore import QThread, pyqtSlot, QCoreApplication, QTimer, pyqtSignal
 
-# Objects
-from transphire.mountworker import MountWorker
-from transphire.processworker import ProcessWorker
-from transphire.inputbox import InputBox
-from transphire.plotworker import PlotWorker
-from transphire.separator import Separator
-from transphire.tabdocker import TabDocker
-from transphire.mountcalculator import MountCalculator
-from transphire import transphire_utils as tu
-from transphire import transphire_import as ti
-
+from . import transphire_utils as tu
+from . import transphire_import as ti
 
 class MainWindow(QMainWindow):
     """
@@ -126,7 +117,6 @@ class MainWindow(QMainWindow):
                             timeout=10
                             )
                     except pe.exceptions.TIMEOUT:
-                        print('Wrong sudo password!')
                         tu.message('Wrong sudo password!')
                     else:
                         if idx == 0:
@@ -1287,12 +1277,14 @@ class MainWindow(QMainWindow):
             for name in folder_names:
                 try:
                     tu.mkdir_p(settings[name])
-                except PermissionError:
-                    tu.message('You do not have permission to write to your specified project directory!')
+                except PermissionError as e:
+                    print(e)
+                    tu.message('You do not have permission to write to your specified project directory! Check the Terminal for the actual error message!')
                     self.enable(True)
                     return None
-                except FileNotFoundError:
-                    tu.message('Project name cannot be empty')
+                except FileNotFoundError as e:
+                    print(e)
+                    tu.message('Project name cannot be empty! Check the Terminal for the actual error message!')
                     self.enable(True)
                     return None
 
@@ -1525,3 +1517,12 @@ class MainWindow(QMainWindow):
             thread.wait()
         print('Bye Bye')
         super(MainWindow, self).closeEvent(event)
+
+# Objects
+from .mountworker import MountWorker
+from .processworker import ProcessWorker
+from .inputbox import InputBox
+from .plotworker import PlotWorker
+from .separator import Separator
+from .tabdocker import TabDocker
+from .mountcalculator import MountCalculator
