@@ -25,8 +25,9 @@ import mrcfile as mrc
 import matplotlib
 matplotlib.use('QT5Agg')
 import matplotlib.image as mi
-from transphire import transphire_import as ti
-from transphire import transphire_utils as tu
+
+from . import transphire_import as ti
+from . import transphire_utils as tu
 
 
 def get_ctf_command(file_sum, file_input, new_name, settings, queue_com, set_name, name):
@@ -805,7 +806,7 @@ def create_export_data(export_data, lines, maximum_string):
             else:
                 length = maximum_string[name]
                 row_string.append('{0:{1}s}'.format(value, length))
-        lines.append('{0}\n'.format('\t'.join(row_string)))
+        lines.append('{0}\n'.format(' '.join(row_string)))
 
 
 def to_partres_file(data, ctf_name, ctf_settings, project_folder, ctf_folder, sum_file, pixel_size_adjust):
